@@ -7,7 +7,7 @@ package A1z::HTML5::Template;
 
 sub NAME { my $self = shift; my $NAME; $NAME = "Fast and Easy Web Apps"; return $NAME; }
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 
 
@@ -1744,11 +1744,16 @@ sub display_gallery_thumbnails
 		
 		error => "",
 
-		images_dir => "$sys{images_dir}",
-		thumbs_dir => "$sys{thumbs_dir}",
+		images_dir => "/images/a1z-html5-template/",
+		thumbs_dir => "/images/a1z-html5-template/thumbs",
 		
-		images_url => "$sys{images_url}",
-		thumbs_url => "$sys{thumbs_url}",
+		images_url => "/images/a1z-html5-template",
+		thumbs_url => "/thumbs/a1z-html5-template/thumbs",
+
+		width => "100",
+		height => "100",
+
+		@_,
 	);
 
 	if (-e -d "$in{images_dir}" and "$in{thumbs_dir}" )
@@ -1761,13 +1766,13 @@ sub display_gallery_thumbnails
 		{
 			if ( $_ and $_ =~ /(.jpg|.gif|.jpeg)$/ )
 			{
-				$out .= qq{<a href="$in{images_url}/$_" title="$_" data-gallery> <img src="$in{thumbs_url}/$_" alt="Image $_" width="100" height="100"> </a> };
+				$out .= qq{<a href="$in{images_url}/$_" title="$_" data-gallery> <img src="$in{thumbs_url}/$_" alt="Image $_" width="$in{width}" height="$in{height}"> </a> };
 			}
 		}
 	}
 	else
 	{
-		$in{error} .= qq{Image directory does not exist or inaccessible};
+		$in{error} .= qq{Image directory does not exist or is inaccessible. Make sure you provided the correct path.};
 	}
 
 	return $out;
@@ -1796,7 +1801,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -1872,7 +1877,7 @@ version 0.13
 
 =head2 VERSION
 
-	0.13
+	0.14
 
 =head1 Installation
 
@@ -2177,6 +2182,9 @@ version 0.13
 		
 		images_url => "{images_url}",
 		thumbs_url => "{thumbs_url}",
+
+		width => "100",
+		height => "100"
 	);
 
 =head1 BUGS
